@@ -38,6 +38,8 @@
 #include "capplet-stock-icons.h"
 #include <../accessibility/keyboard/accessibility-keyboard.h>
 
+#include "gnome-keyboard-properties-xkb.h"
+
 enum
 {
 	RESPONSE_APPLY = 1,
@@ -76,7 +78,7 @@ blink_from_widget (GConfPropertyEditor *peditor, const GConfValue *value)
 	GConfValue *new_value;
 
 	new_value = gconf_value_new (GCONF_VALUE_INT);
-	gconf_value_set_int (new_value, 2600 - (int) gconf_value_get_float (value));
+	gconf_value_set_int (new_value, 2600 - gconf_value_get_int (value));
 
 	return new_value;
 }
@@ -88,8 +90,8 @@ blink_to_widget (GConfPropertyEditor *peditor, const GConfValue *value)
 	gint current_rate;
 
 	current_rate = gconf_value_get_int (value);
-	new_value = gconf_value_new (GCONF_VALUE_FLOAT);
-	gconf_value_set_float (new_value, CLAMP (2600 - current_rate, 100, 2500));
+	new_value = gconf_value_new (GCONF_VALUE_INT);
+	gconf_value_set_int (new_value, CLAMP (2600 - current_rate, 100, 2500));
 
 	return new_value;
 }
@@ -131,8 +133,6 @@ setup_dialog (GladeXML       *dialog,
 	program = gnome_program_get ();
 
 	capplet_init_stock_icons ();
-        gtk_image_set_from_stock (GTK_IMAGE (WID ("repeat_image")), KEYBOARD_REPEAT, keyboard_capplet_icon_get_size());
-        gtk_image_set_from_stock (GTK_IMAGE (WID ("cursor_image")), KEYBOARD_CURSOR, keyboard_capplet_icon_get_size());
 	
 	peditor = gconf_peditor_new_boolean
 		(changeset, "/desktop/gnome/peripherals/keyboard/repeat", WID ("repeat_toggle"), NULL);
@@ -140,14 +140,10 @@ setup_dialog (GladeXML       *dialog,
 
 	gconf_peditor_new_numeric_range
 		(changeset, "/desktop/gnome/peripherals/keyboard/delay", WID ("repeat_delay_scale"),
-		 "conv-to-widget-cb",   gconf_value_int_to_float,
-		 "conv-from-widget-cb", gconf_value_float_to_int,
 		 NULL);
 
 	gconf_peditor_new_numeric_range
 		(changeset, "/desktop/gnome/peripherals/keyboard/rate", WID ("repeat_speed_scale"),
-		 "conv-to-widget-cb",   gconf_value_int_to_float,
-		 "conv-from-widget-cb", gconf_value_float_to_int,
 		 NULL);
 
 	peditor = gconf_peditor_new_boolean
@@ -170,6 +166,10 @@ setup_dialog (GladeXML       *dialog,
 	gconf_peditor_new_boolean
 		(changeset, "/desktop/gnome/typing_break/allow_postpone", WID ("break_postponement_toggle"), NULL);
 	g_signal_connect (G_OBJECT (WID ("keyboard_dialog")), "response", (GCallback) dialog_response, changeset);
+	
+	gtk_label_set_use_markup (GTK_LABEL (GTK_BIN (WID ("break_enabled_toggle"))->child), TRUE);
+	
+        setup_xkb_tabs(dialog,changeset);
 }
 
 static void
@@ -211,8 +211,10 @@ main (int argc, char **argv)
 	GConfChangeSet *changeset;
 	GladeXML       *dialog;
 
-	static gboolean apply_only;
-	static gboolean get_legacy;
+	static gboolean apply_only = FALSE;
+	static gboolean get_legacy = FALSE;
+	static gboolean switch_to_typing_break_page = FALSE;
+
 	static struct poptOption cap_options[] = {
 		{ "apply", '\0', POPT_ARG_NONE, &apply_only, 0,
 		  N_("Just apply settings and quit (compatibility only; now handled by daemon)"), NULL },
@@ -220,7 +222,8 @@ main (int argc, char **argv)
 		  N_("Just apply settings and quit (compatibility only; now handled by daemon)"), NULL },
 		{ "get-legacy", '\0', POPT_ARG_NONE, &get_legacy, 0,
 		  N_("Retrieve and store legacy settings"), NULL },
-//		{ "set_page",
+		{ "typing-break", '\0', POPT_ARG_NONE, &switch_to_typing_break_page, 0,
+		  N_("Start the page with the typing break settings showing"), NULL },
 		{ NULL, '\0', 0, NULL, 0, NULL, NULL }
 	};
 
@@ -245,8 +248,11 @@ main (int argc, char **argv)
 		changeset = NULL;
 		dialog = create_dialog ();
 		setup_dialog (dialog, changeset);
+		if (switch_to_typing_break_page) {
+			gtk_notebook_set_current_page (GTK_NOTEBOOK (WID ("keyboard_notebook")), 1);
+		}
 		capplet_set_icon (WID ("keyboard_dialog"),
-			"keyboard-capplet.png");
+				  "keyboard-capplet.png");
 		gtk_widget_show (WID ("keyboard_dialog"));
 		gtk_main ();
 	}
