@@ -39,7 +39,7 @@ static void update_gconf_key_from_selection (GtkTreeSelection *selection,
 					     const gchar      *gconf_key);
 static void load_theme_names                (GtkTreeView        *tree_view,
 					     GList              *theme_list,
-					     gchar              *default_theme);
+					     const gchar        *default_theme);
 static char *path_to_theme_id               (const char *path);
 
 
@@ -65,6 +65,35 @@ cb_dialog_response (GtkDialog *dialog, gint response_id)
     gtk_widget_hide (GTK_WIDGET (dialog));
 }
 
+static gint
+details_tree_sort_func (GtkTreeModel *model,
+			GtkTreeIter  *a,
+			GtkTreeIter  *b,
+			gpointer      user_data)
+{
+  gchar *a_name = NULL;
+  gchar *b_name = NULL;
+  guint a_flag = FALSE;
+  guint b_flag = FALSE;
+  gint retval;
+
+  gtk_tree_model_get (model, a,
+		      THEME_NAME_COLUMN, &a_name,
+		      THEME_FLAG_COLUMN, &a_flag,
+		      -1);
+  gtk_tree_model_get (model, b,
+		      THEME_NAME_COLUMN, &b_name,
+		      THEME_FLAG_COLUMN, &b_flag,
+		      -1);
+
+  retval = gnome_theme_manager_sort_func (a_name, b_name, a_flag, b_flag);
+
+  g_free (a_name);
+  g_free (b_name);
+
+  return retval;
+}
+
 static void
 setup_tree_view (GtkTreeView *tree_view,
 		 GCallback    changed_callback,
@@ -75,9 +104,10 @@ setup_tree_view (GtkTreeView *tree_view,
   GtkCellRenderer *renderer;
 
   model = (GtkTreeModel *) gtk_list_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT);
-  gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model), 0, gnome_theme_manager_tree_sort_func, NULL, NULL);
+  gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model), 0, details_tree_sort_func, NULL, NULL);
   gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model), 0, GTK_SORT_ASCENDING);
   gtk_tree_view_set_model (tree_view, model);
+
   selection = gtk_tree_view_get_selection (tree_view);
   gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
   g_signal_connect (G_OBJECT (selection), "changed", changed_callback, dialog);
@@ -86,9 +116,8 @@ setup_tree_view (GtkTreeView *tree_view,
   gtk_tree_view_insert_column_with_attributes (tree_view,
  					       -1, NULL,
  					       renderer,
- 					       "markup", THEME_NAME_COLUMN,
+ 					       "text", THEME_NAME_COLUMN,
  					       NULL);
-
 }
 
 
@@ -129,7 +158,22 @@ window_theme_selection_changed (GtkTreeSelection *selection,
     wm_settings.theme = window_theme_name;
     gnome_window_manager_change_settings (window_manager, &wm_settings);
   }
+  g_free (window_theme_name);
+}
 
+static void
+gnome_theme_installer_run_cb (GtkWidget *button,
+			      GtkWidget *parent_window)
+{
+  gnome_theme_installer_run (parent_window, NULL, FALSE);
+}
+
+
+static void
+gnome_icon_theme_installer_run_cb (GtkWidget *button,
+			      GtkWidget *parent_window)
+{
+  gnome_theme_installer_run (parent_window, NULL, TRUE);
 }
 
 static void
@@ -142,7 +186,7 @@ icon_theme_selection_changed (GtkTreeSelection *selection,
 static void
 load_theme_names (GtkTreeView *tree_view,
 		  GList       *theme_list,
-		  gchar       *default_theme)
+		  const gchar *default_theme)
 {
   GList *list;
   GtkTreeModel *model;
@@ -169,7 +213,7 @@ load_theme_names (GtkTreeView *tree_view,
 
       gtk_list_store_prepend (GTK_LIST_STORE (model), &iter);
 
-      if (strcmp (default_theme, name) == 0)
+      if (default_theme && strcmp (default_theme, name) == 0)
 	is_default = TRUE;
       else
 	is_default = FALSE;
@@ -239,7 +283,6 @@ update_gconf_key_from_selection (GtkTreeSelection *selection,
   g_object_unref (client);
 }
 
-
 void
 gnome_theme_details_init (void)
 {
@@ -269,19 +312,19 @@ gnome_theme_details_init (void)
 
   /* gtk themes */
   widget = WID ("control_install_button");
-  g_signal_connect_swapped (G_OBJECT (widget), "clicked", G_CALLBACK (gnome_theme_installer_run), parent);
+  g_signal_connect (G_OBJECT (widget), "clicked", G_CALLBACK (gnome_theme_installer_run_cb), parent);
   widget = WID ("control_manage_button");
   g_signal_connect (G_OBJECT (widget), "clicked", G_CALLBACK (gnome_theme_manager_show_manage_themes), dialog);
 
   /* window manager themes */
   widget = WID ("window_install_button");
-  g_signal_connect_swapped (G_OBJECT (widget), "clicked", G_CALLBACK (gnome_theme_installer_run), parent);
+  g_signal_connect (G_OBJECT (widget), "clicked", G_CALLBACK (gnome_icon_theme_installer_run_cb), parent);
   widget = WID ("window_manage_button");
   g_signal_connect (G_OBJECT (widget), "clicked", G_CALLBACK (gnome_theme_manager_window_show_manage_themes), dialog);
 
   /* icon themes */
   widget = WID ("icon_install_button");
-  g_signal_connect_swapped (G_OBJECT (widget), "clicked", G_CALLBACK (gnome_theme_installer_run), parent);
+  g_signal_connect (G_OBJECT (widget), "clicked", G_CALLBACK (gnome_theme_installer_run_cb), parent);
   widget = WID ("icon_manage_button");
   g_signal_connect (G_OBJECT (widget), "clicked", G_CALLBACK (gnome_theme_manager_icon_show_manage_themes), dialog);
 
@@ -347,6 +390,9 @@ gnome_theme_details_reread_themes_from_disk (void)
   gboolean have_window_theme;
   gboolean have_icon_theme;
 
+  
+  gnome_theme_details_init ();
+
   dialog = gnome_theme_manager_get_theme_dialog ();
   window_manager = gnome_wm_manager_get_current (gdk_display_get_default_screen (gdk_display_get_default ()));
   notebook = WID ("theme_notebook");
@@ -371,7 +417,7 @@ gnome_theme_details_reread_themes_from_disk (void)
     {
       have_gtk_theme = TRUE;
       gtk_widget_show (WID ("control_theme_vbox"));
-      load_theme_names (GTK_TREE_VIEW (WID ("control_theme_treeview")), string_list, GTK_THEME_DEFAULT_NAME);
+      load_theme_names (GTK_TREE_VIEW (WID ("control_theme_treeview")), string_list, gtk_theme_default_name);
       g_list_free (string_list);
     }
   g_list_free (theme_list);
@@ -394,7 +440,7 @@ gnome_theme_details_reread_themes_from_disk (void)
     {
       have_window_theme = TRUE;
       gtk_widget_show (WID ("window_theme_vbox"));
-      load_theme_names (GTK_TREE_VIEW (WID ("window_theme_treeview")), string_list, WINDOW_THEME_DEFAULT_NAME);
+      load_theme_names (GTK_TREE_VIEW (WID ("window_theme_treeview")), string_list, window_theme_default_name);
       g_list_free (string_list);
     }
   g_list_free (theme_list);
@@ -419,7 +465,7 @@ gnome_theme_details_reread_themes_from_disk (void)
     {
       have_icon_theme = TRUE;
       gtk_widget_show (WID ("icon_theme_vbox"));
-      load_theme_names (GTK_TREE_VIEW (WID ("icon_theme_treeview")), string_list, ICON_THEME_DEFAULT_NAME);
+      load_theme_names (GTK_TREE_VIEW (WID ("icon_theme_treeview")), string_list, icon_theme_default_name);
       g_list_free (string_list);
     }
   g_list_free (theme_list);
@@ -507,6 +553,8 @@ gnome_theme_details_update_from_gconf (void)
   GnomeWindowManager *window_manager;
   GnomeWMSettings wm_settings;
 
+  gnome_theme_details_init ();
+
   window_manager = gnome_wm_manager_get_current (gdk_display_get_default_screen (gdk_display_get_default ()));
 
   client = gconf_client_get_default ();
